==> winnie-0.1.46.tgz: package/properties/edit.js <==
'use strict';

var Ui = require('kenga/utils');
require('kenga/key-codes');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Ui__default = /*#__PURE__*/_interopDefaultLegacy(Ui);

var CURSOR_OPTIONS = ['alias', 'all-scroll', 'auto', 'cell', 'context-menu', 'col-resize', 'copy', 'crosshair', 'default', 'e-resize', 'ew-resize', 'grab', 'grabbing', 'help', 'move', 'n-resize', 'ne-resize', 'nesw-resize', 'ns-resize', 'nw-resize', 'nwse-resize', 'no-drop', 'none', 'not-allowed', 'pointer', 'progress', 'row-resize', 's-resize', 'se-resize', 'sw-resize', 'text', 'w-resize', 'wait', 'zoom-in', 'zoom-out'];
var dataLists = new Set();

function dataListOf(propertyName, options) {
  var id = "p-d-winnie-".concat(propertyName);

  if (!dataLists.has(id)) {
    var list = document.createElement('datalist');
    list.setAttribute('id', id);
    list.innerHTML = options.map(function (item) {
      return "<option>".concat(item, "</option>");
    }).join('');
    document.body.appendChild(list);
    dataLists.add(id);
  }

  return id;
}

function onEdit(item, viewCell) {
  if (item.name === 'cursor') {
    viewCell.innerHTML = '';
    var listId = dataListOf(item.name, CURSOR_OPTIONS);
    var input = document.createElement('input');
    input.setAttribute('id', "p-".concat(listId));
    input.setAttribute('list', listId);

    if (item.value) {
      input.value = item.value;
    }

    input.classList.add('p-winnie-cell-editor');

    var valueChanged = function valueChanged(event) {
      item.silent = true;
      item.value = input.value;
    };

    Ui__default['default'].on(input, Ui__default['default'].Events.CHANGE, valueChanged);
    Ui__default['default'].on(input, Ui__default['default'].Events.INPUT, valueChanged);
    Ui__default['default'].on(input, Ui__default['default'].Events.CLICK, function (event) {
      event.stopPropagation();
    });
    Ui__default['default'].on(input, Ui__default['default'].Events.KEYDOWN, function (event) {
      event.stopPropagation();
    });
    viewCell.appendChild(input);
  }
}

module.exports = onEdit;

==> winnie-0.1.55.tgz: package/properties/edit.js <==
'use strict';

var Ui = require('kenga/utils');
require('kenga/key-codes');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Ui__default = /*#__PURE__*/_interopDefaultLegacy(Ui);

var CURSOR_OPTIONS = ['alias', 'all-scroll', 'auto', 'cell', 'context-menu', 'col-resize', 'copy', 'crosshair', 'default', 'e-resize', 'ew-resize', 'grab', 'grabbing', 'help', 'move', 'n-resize', 'ne-resize', 'nesw-resize', 'ns-resize', 'nw-resize', 'nwse-resize', 'no-drop', 'none', 'not-allowed', 'pointer', 'progress', 'row-resize', 's-resize', 'se-resize', 'sw-resize', 'text', 'w-resize', 'wait', 'zoom-in', 'zoom-out'];
var dataLists = new Set();

function dataListOf(propertyName, options) {
  var id = "p-d-winnie-".concat(propertyName);

  if (!dataLists.has(id)) {
    var list = document.createElement('datalist');
    list.setAttribute('id', id);
    list.innerHTML = options.map(function (item) {
      return "<option>".concat(item, "</option>");
    }).join('');
    document.body.appendChild(list);
    dataLists.add(id);
  }

  return id;
}

function onEdit(item, viewCell) {
  if (item.name === 'cursor') {
    viewCell.innerHTML = '';
    var listId = dataListOf(item.name, CURSOR_OPTIONS);
    var input = document.createElement('input');
    input.setAttribute('id', "p-".concat(listId));
    input.setAttribute('list', listId);

    if (item.value) {
      input.value = item.value;
    }

    input.classList.add('p-winnie-cell-editor');

    var valueChanged = function valueChanged(event) {
      item.silent = true;
      item.value = input.value;
    };

    Ui__default["default"].on(input, Ui__default["default"].Events.CHANGE, valueChanged);
    Ui__default["default"].on(input, Ui__default["default"].Events.INPUT, valueChanged);
    Ui__default["default"].on(input, Ui__default["default"].Events.CLICK, function (event) {
      event.stopPropagation();
    });
    Ui__default["default"].on(input, Ui__default["default"].Events.KEYDOWN, function (event) {
      event.stopPropagation();
    });
    viewCell.appendChild(input);
  }
}

module.exports = onEdit;
